@@ -50,6 +50,7 @@ write_metadata <- function(){
 #'
 write_session_info <- function(){
    session_info <- get_log_element("session_info") %>%
+      capture.output() %>%
       # remove extra dashes on title lines
       map_chr(~ ifelse(nchar(.x) > 80 & grepl("\u2500\u2500\u2500\u2500", .x),
                    substring(.x, 1, 80),
@@ -62,6 +63,28 @@ write_session_info <- function(){
    return(session_info)
 }
 
+#' Format repo URLs for writing
+#'
+#' @return A vector of file name and path prefixed
+#'
+#' @noRd
+#'
+write_repo_urls <- function(){
+   repo_urls <- ifelse(is.na(get_log_element("repo_urls")),
+                       "Repo URLs not able to be determined",
+                       map2(
+                          names(get_log_element("repo_urls")),
+                          get_log_element("repo_urls"),
+                          ~paste(paste0(.x, ": "),
+                                 paste0(.y, collapse = ", "))
+                       ) %>%
+                          unname() %>%
+                          unlist()
+   )
+
+   return(repo_urls)
+}
+
 #' Format file name and path for writing
 #'
 #' @return A vector of file name and path prefixed
@@ -259,10 +282,14 @@ write_output <- function() {
 #'
 #' @noRd
 #'
-write_result <- function() {
+write_result <- function(file) {
    result <- get_log_element("result")
 
-   c("\nResult:", paste0("\t", capture.output(result$value)))
+   if (is_rmarkdown(file)) {
+      c("\nResult:", paste0("\t", capture.output(result)))
+   } else {
+      c("\nResult:", paste0("\t", capture.output(result$value)))
+   }
 }
 
 #' Format lint results for writing
@@ -274,6 +301,10 @@ write_result <- function() {
 write_lint_results <- function(){
    lint_results <- get_log_element("lint_results")
 
+   if (length(lint_results) == 0) {
+      return("")
+   }
+
    lint_df <- as.data.frame(lint_results)
 
    lint_df$lint_messages <- paste0("Line ",
